<?php
$TRANSLATIONS = array(
"Could not load template" => "Невозможно загрузить шаблон",
"Saved" => "Сохранено",
"Reset" => "Сброс",
"An error occurred" => "Произошла ошибка",
"Sharing email - public link shares (HTML)" => "Письмо об открытии общего доступа  - публичные ссылки доступа (HTML)",
"Sharing email - public link shares (plain text fallback)" => "Письмо об открытии общего доступа  - публичные ссылки доступа (простой текст)",
"Sharing email (HTML)" => "Письмо об открытии общего доступа (HTML)",
"Sharing email (plain text fallback)" => "Письмо об открытии общего доступа (простой текст)",
"Lost password mail" => "Письмо восстановления пароля",
"New user email (HTML)" => "Новый шаблон письма (HTML)",
"New user email (plain text fallback)" => "Новый шаблон письма (обычный текст)",
"Activity notification mail" => "Письмо уведомления об активности",
"Mail Templates" => "Шаблоны электронных писем",
"Theme" => "Тема",
"Template" => "Шаблон",
"Please choose a template" => "Выберите шаблон",
"Save" => "Сохранить"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);";
